Package: EnrichIntersect
Type: Package
Title: Enrichment Analysis and Intersecting Sankey Diagram
Version: 1.0
URL: https://github.com/ocbe-uio/EnrichIntersect
BugReports: https://github.com/ocbe-uio/EnrichIntersect/issues
Authors@R: c(person("Zhi", "Zhao", email = "zhi.zhao@medisin.uio.no", role = c("aut","cre")), person("Manuela", "Zucknick", email = "manuela.zucknick@medisin.uio.no", role = c("aut")), person("Tero", "Aittokallio", email = "t.a.aittokallio@medisin.uio.no", role = c("ctb")))
Description: A flexible tool for enrichment analysis based on user-defined sets. It allows users to perform over-representation analysis of the custom sets among any specified ranked feature list, hence making enrichment analysis applicable to various types of data from different scientific fields. 'EnrichIntersect' also enables an interactive means to visualize identified associations based on, for example, the mix-lasso model (Zhao et al., 2022 <doi:10.1016/j.isci.2022.104767>) or similar methods.
License: MIT + file LICENSE
Depends: R (>= 4.0)
Encoding: UTF-8
LinkingTo: Rcpp, RcppArmadillo
Imports: Rcpp, ggplot2, dplyr, networkD3, jsonlite, htmlwidgets,
        webshot2, stats, methods, grDevices
Suggests: knitr
LazyData: true
VignetteBuilder: knitr
NeedsCompilation: yes
Config/roxygen2/version: 8.0.0
Packaged: 2026-05-30 00:19:06 UTC; zhiz
Author: Zhi Zhao [aut, cre],
  Manuela Zucknick [aut],
  Tero Aittokallio [ctb]
Maintainer: Zhi Zhao <zhi.zhao@medisin.uio.no>
Repository: CRAN
Date/Publication: 2026-05-30 02:10:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-05-30 07:03:05 UTC; unix
Archs: EnrichIntersect.so.dSYM
