# Generated by roxygen2: do not edit by hand

export(enrichment)
export(intersectSankey)
import(ggplot2)
importFrom(Rcpp,sourceCpp)
importFrom(dplyr,"%>%")
importFrom(grDevices,hcl.colors)
importFrom(htmlwidgets,onRender)
importFrom(htmlwidgets,saveWidget)
importFrom(jsonlite,toJSON)
importFrom(methods,hasArg)
importFrom(networkD3,JS)
importFrom(networkD3,sankeyNetwork)
importFrom(stats,p.adjust)
importFrom(webshot2,webshot)
useDynLib(EnrichIntersect, .registration = TRUE)
