# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

enrichment_core_original <- function(x, set_indices, alpha = 0.0, normalize = TRUE, permute_n = 100L) {
    .Call(`_EnrichIntersect_enrichment_core_original`, x, set_indices, alpha, normalize, permute_n)
}

