#' @keywords internal
#' @aliases EnrichIntersect-package NULL
#'
#'
"_PACKAGE"

## usethis namespace: start
#' @useDynLib EnrichIntersect, .registration = TRUE
#' @importFrom Rcpp sourceCpp
## usethis namespace: end
NULL

