#' @title Data set 'cancers_drug_groups'
#'
#' @description
#' Data set 'cancers_drug_groups' is a list including a score dataframe with 
#' 147 drugs as rows and 19 cancer types as columns, and a dataframe with 9 
#' self-defined drug groups (1st column) of the 147 drugs (2nd column). More 
#' details of the data can be found in the results of paper 'Tissue-specific 
#' identification of multi-omics features for pan-cancer drug response 
#' prediction' by Zhao Z., Wang S. Zucknick M. and Aittokallio T. (2022).
#'
#' @return No return value.
#'
#' @references Zhao Z, Wang S, Zucknick M and Aittokallio T (2022). 
#' \emph{Tissue-specific identification of multi-omics features for 
#' pan-cancer drug response prediction}. iScience, 25(8): 104767.
#'
#' @examples
#' # Load data
#' data(cancers_drug_groups, package = "EnrichIntersect")
#'
"cancers_drug_groups"
