% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/enrichment.R
\name{enrichment}
\alias{enrichment}
\title{Plot enrichment map}
\usage{
enrichment(
  x,
  custom.set,
  alpha = 0,
  normalize = TRUE,
  permute.n = 100,
  padj.method = "none",
  pvalue.cutoff = 0.05,
  angle = 45,
  match.feature = c("rownames", "colnames"),
  ...
)
}
\arguments{
\item{x}{a vector or matrix of scores to be enriched}

\item{custom.set}{a self-defined set. The first column contains feature names,
and the second column, preferably named "group", contains group names.}

\item{alpha}{exponent weight of the score of ordered features.}

\item{normalize}{logical value to determine if normalizing enrichment scores.}

\item{permute.n}{number of custom-set permutations for significance testing.}

\item{padj.method}{correction method passed to stats::p.adjust.}

\item{pvalue.cutoff}{cutoff for both unadjusted and adjusted p-value.}

\item{angle}{angle of rotating x-axis labels.}

\item{match.feature}{one of "rownames" or "colnames". Default is "rownames",
which keeps the original EnrichIntersect behavior.}

\item{...}{other arguments}
}
\value{
A list including S, pvalue, and g.
}
\description{
Plot enrichment map through a vector or matrix of scores and a self-defined
set that summarizes a few groups of the names of the vector or matrix.
}
